##  Importing Tech Categories from the Reference Catalog
As an admin, you can view all TBM hierarchies and import all or specific TBM-based tech categories into your workspace.
**Note**
Before importing TBM hierarchies, ensure that the meta model configuration of the workspace supports at least level 3 hierarchy for the tech category fact sheet.
To import TBM-based tech categories, follow these steps:
  1. In the administration area, navigate to the Reference Catalog section, then go to the Tech Category tab.
  2. Under Import TBM Taxonomy, click Import TBM. You land on the page displaying TBM-based tech categories available for import.
  3. Select the tech categories that you want to import, then click Import and Link.


This imports any nonexistent tech categories along with their full hierarchy and automatically links existing tech category fact sheets with the same name to relevant catalog items.
**Tip**
As an alternative method of importing TBM-based tech categories, you can download the TBM Taxonomy Excel template and then upload it to the inventory using the Excel import option. To learn more, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
